==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/re/re-substring.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] = 
"$Id: re-substring.c,v 1.7 2004/01/28 15:56:45 lwa Exp $";

#include "config.h"

#include <sys/types.h>

#include <stdlib.h>
#include <string.h>
#include "re.h"

#if! HAVE_STRCASESTR
/* use glibc version */
char * strcasestr (const char *phaystack, const char *pneedle);
#endif

static void re_close(RE *re) {
  if (re->code)
    free(re->code);
  re->code = NULL;
}
#include <stdio.h>
static int re_exec_icase(RE *re, char *string) {
  char *ret;
  ret = strcasestr(string, re->code);
  return ret == NULL;
}

static int re_exec(RE *re, char *string) {
  char *ret;
  ret = strstr(string, re->code);
  return ret == NULL;
}

static int re_compile(RE *re, char *pattern, int icase) {
  re->code = strdup(pattern);
  if (re->code == NULL) {
    re->err = RE_ERR_MEMORY;
    re->errstr = "memory";
  } else {
    re->err = 0;
  }
  if (icase) {
    re->exec = re_exec_icase;
  } else {
    re->exec = re_exec;
  }
  return re->err;
}


RE re_strstr = {
  re_compile,
  re_exec,
  re_close,
  0,
  0,
};

==> lmtpd-0.10.4.tar.gz: lmtpd-0.10.4/re/re-substring.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED = 
"$Id: re-substring.c,v 1.8 2004/10/26 09:59:21 lwa Exp $";



#include <sys/types.h>

#include <stdlib.h>
#include <string.h>
#include "re.h"

#if! HAVE_STRCASESTR
/* use glibc version */
char * strcasestr (const char *phaystack, const char *pneedle);
#endif

static void re_close(RE *re) {
  if (re->code)
    free(re->code);
  re->code = NULL;
}
#include <stdio.h>
static int re_exec_icase(RE *re, char *string) {
  char *ret;
  ret = strcasestr(string, re->code);
  return ret == NULL;
}

static int re_exec(RE *re, char *string) {
  char *ret;
  ret = strstr(string, re->code);
  return ret == NULL;
}

static int re_compile(RE *re, char *pattern, int icase) {
  re->code = strdup(pattern);
  if (re->code == NULL) {
    re->err = RE_ERR_MEMORY;
    re->errstr = "memory";
  } else {
    re->err = 0;
  }
  if (icase) {
    re->exec = re_exec_icase;
  } else {
    re->exec = re_exec;
  }
  return re->err;
}


RE re_strstr = {
  re_compile,
  re_exec,
  re_close,
  0,
  0,
};
